## TurnGen: a household chores turn generator
## Copyright (C) 2006 Angelo "Encelo" Theodorou
##

import sys

import gettext
gettext.bindtextdomain('turngen', 'po')
gettext.textdomain('turngen')
_ = gettext.gettext


class Menu:
	"""Shell menu interface"""
	def __init__(self, db):
		"""Set db attribute and valid choices list"""
		self.db = db
		self.valid = [1, 2, 3, 4, 5, 6, 7, 8]
		self.main()


	def main(self):
		"""The menu loop"""
		self.print_menu()
		while(1):
			choice = self.input()
			self.select(choice)


	def select(self, choice):
		"""Do an action based on user choice"""
		if choice == 1: # Show users table
			print _('Users table:')
			print
			fetch = self.db.fetch_table('users')
			self.db.print_fetch(fetch)
			print
		elif choice == 2: # Show activities table
			print _('Activities table:')
			print
			fetch = self.db.fetch_table('activities')
			self.db.print_fetch(fetch)
			print
		elif choice == 3: # Show data table
			fetch = self.db.fetch_joined_data()
			self.db.print_fetch(fetch)
			print
		elif choice == 4: # Show rankings
			presence = raw_input(_('Presence (eg. "0-1-2"): '))
			presence_l = self.db.dec_presence(presence)
			if self.db.valid_presence(presence_l) == True:
				activity_id = input(_('Activity id (eg. "1"): '))
				if self.db.valid_activity_id(activity_id) == True:
					activity = self.db.get_activity_name(activity_id)
					print
					print _('Rankings for activity "%s" where presence is "%s":') % (activity, presence)
					print
					fetch = self.db.fetch_ranking(presence_l, activity_id)
					self.db.print_fetch(fetch)
					print
			pass
		elif choice == 5: # Query for the laziest
			presence = raw_input(_('Presence (eg. "0-1-2"): '))
			presence_l = self.db.dec_presence(presence)
			if self.db.valid_presence(presence_l) == True:
				activity_id = input(_('Activity id (eg. "1"): '))
				if self.db.valid_activity_id(activity_id) == True:
					user_ids = self.db.get_laziest_users_id(presence_l, activity_id)
					users = []
					activity = self.db.get_activity_name(activity_id)
					print
					print _('Laziest on "%s" where presence is "%s" is:') % (activity, presence),
					for user_id in user_ids:
						user = self.db.get_user_name(user_id)
						if user_ids.index(user_id) != len(user_ids)-1:
							print '"%s" (%s),' % (user, user_id),
						else:
							print '"%s" (%s)' % (user, user_id),
					print
				else:
					print _('Activity id %s is invalid!') % activity_id
			else:
				print _('Presence string "%s" is invalid!') % presence
		elif choice == 6: # Insert an action
			presence = raw_input(_('Presence (eg. "0-1-2"): '))
			presence_l = self.db.dec_presence(presence)
			if self.db.valid_presence(presence_l) == True:
				user_id = input(_('User id (eg. "1"): '))
				if self.db.valid_user_id(user_id) == True:
					activity_id = input(_('Activity id (eg. "1"): '))
					if self.db.valid_activity_id(activity_id) == True:
						if user_id in presence_l:
							user = self.db.get_user_name(user_id)
							activity = self.db.get_activity_name(activity_id)
							self.db.insert_data(presence_l, user_id, activity_id)
							print
							print _('Inserted action "%s" for user "%s" where presence is "%s"') % (activity, user, presence)
						else:
							print _('User id %s not in presence string "%s"!') % (user_id, presence)
					else:
						print _('Activity id %s is invalid!') % activity_id
				else:
					print _('User id %s is invalid!') % user_id
			else:
				print _('Presence string "%s" is invalid!') % presence
		elif choice == 7: # Remove an action
			data_id = raw_input(_('Data id (eg. "1"): '))
			if self.db.valid_data_id(data_id) == True:
				self.db.remove_data(data_id)
				print
				print _('Removed action %s') % data_id
		elif choice == 8: # Quit
			sys.exit()


	def print_menu(self):
		print
		print _('TurnGen 0.2, (C) 2006 by Angelo "Encelo" Theodorou')
		print
		print _('What do you want to do?')
		print   '_________________________'
		print _('1: Show users table')
		print _('2: Show activities table')
		print _('3: Show data table')
		print _('4: Show rankings')
		print   '_________________________'
		print _('5: Query for the laziest')
		print _('6: Insert an action')
		print _('7: Remove an action')
		print   '_________________________'
		print _('8: Quit')
		print

	
	def input(self):
		print _('=> (? for menu):'),
		try:
			c = raw_input()
		except KeyboardInterrupt:
			print
			print _('CTRL-c caught, exiting')
			sys.exit(0)
		except EOFError:
			print
			print _('CTRL-d caught, exiting')
			sys.exit(0)
		
		print
		if c == '?':
			self.print_menu()
			return 0
	
		try:
			valid = int(c) in self.valid
		except ValueError:
			print _('Not a valid option!')
			return 0

		if valid:
			return int(c)
		else:
			print _("Option %s doesn't exist!") % c
			return 0
